==> piwigo-2.1.5.zip: piwigo/plugins/LocalFilesEditor/language/tr_TR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokal Ayarlar';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Sablonlar';
$lang['locfiledit_onglet_lang'] = 'Dil Destegi';
$lang['locfiledit_onglet_plug'] = 'Kisisel Plugin';
$lang['locfiledit_cant_save'] = 'Seçili dosyanin yazilabilirlik izni yok. Lütfen "include/" klasörünü yazilabilir yapiniz (chmod).';
$lang['locfiledit_newfile'] = 'Böyle bir dosya bulunamadi ya da Lokal dosya editörü ile yaratildi';
$lang['locfiledit_save_config'] = 'Dosya basariyla yazildi.';
$lang['locfiledit_show_default'] = 'Referans dosyayi göster: ';
$lang['locfiledit_save_bak'] = 'Yedekleme dosyasi basariyla kaydedildi.';
$lang['locfiledit_saved_bak'] = 'Yedekleme dosyasi yaratildi (%s)';
$lang['locfiledit_save_file'] = 'Dosyayi kaydet';
$lang['locfiledit_choose_file'] = 'Editlenen dosyayi seç';
$lang['locfiledit_edit'] = 'Editle';
$lang['locfiledit_restore'] = 'Yedekleme dosyasini geri yükle';
$lang['locfiledit_restore_confirm'] = 'Lütfen onayla? 
bir sonraki kaydetmeye kadar geri yükleme yapilamayacak.';
$lang['locfiledit_bak_loaded1'] = 'yedekleme dosyasi yüklendi.';
$lang['locfiledit_bak_loaded2'] = 'Geri yükledikten sonra save etmeyi unutmayiniz.';
$lang['locfiledit_syntax_error'] = 'Syntax error! Dosya kayit edilemiyor.';
$lang['locfiledit_enable_editarea'] = 'Editleme açik';
$lang['locfiledit_disable_editarea'] = 'Editleme kapali';
$lang['locfiledit_new_tpl'] = 'Yeni Dosya Yarat';
$lang['locfiledit_new_filename'] = 'Dosya Adi';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Bos Sayfa';
$lang['locfiledit_parent_directory'] = 'Üst Klasör';
$lang['locfiledit_filename_error'] = 'Dosya adinda tanimlanamayan karakterler kullanilmis.';
$lang['locfiledit_file_already_exists'] = 'Bu dosya zaten var.';
$lang['locfiledit_model_error'] = 'Model seçmek zorundasin.';
$lang['locfiledit_empty_filename'] = 'Adi doldurmak zorundasin.';
$lang['locfiledit_webmaster_only'] = 'Sadece yöneticiler dosyalari degistirebilir .';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/tr_TR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokal Ayarlar';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Sablonlar';
$lang['locfiledit_onglet_lang'] = 'Dil Destegi';
$lang['locfiledit_onglet_plug'] = 'Kisisel Plugin';
$lang['locfiledit_cant_save'] = 'Seçili dosyanin yazilabilirlik izni yok. Lütfen "local/" klasörünü yazilabilir yapiniz (chmod).';
$lang['locfiledit_newfile'] = 'Böyle bir dosya bulunamadi ya da Lokal dosya editörü ile yaratildi';
$lang['locfiledit_save_config'] = 'Dosya basariyla yazildi.';
$lang['locfiledit_show_default'] = 'Referans dosyayi göster: ';
$lang['locfiledit_save_bak'] = 'Yedekleme dosyasi basariyla kaydedildi.';
$lang['locfiledit_saved_bak'] = 'Yedekleme dosyasi yaratildi (%s)';
$lang['locfiledit_save_file'] = 'Dosyayi kaydet';
$lang['locfiledit_choose_file'] = 'Editlenen dosyayi seç';
$lang['locfiledit_edit'] = 'Editle';
$lang['locfiledit_restore'] = 'Yedekleme dosyasini geri yükle';
$lang['locfiledit_restore_confirm'] = 'Lütfen onayla? 
bir sonraki kaydetmeye kadar geri yükleme yapilamayacak.';
$lang['locfiledit_bak_loaded1'] = 'yedekleme dosyasi yüklendi.';
$lang['locfiledit_bak_loaded2'] = 'Geri yükledikten sonra save etmeyi unutmayiniz.';
$lang['locfiledit_syntax_error'] = 'Syntax error! Dosya kayit edilemiyor.';
$lang['locfiledit_enable_editarea'] = 'Editleme açik';
$lang['locfiledit_disable_editarea'] = 'Editleme kapali';
$lang['locfiledit_new_tpl'] = 'Yeni Dosya Yarat';
$lang['locfiledit_new_filename'] = 'Dosya Adi';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Bos Sayfa';
$lang['locfiledit_parent_directory'] = 'Üst Klasör';
$lang['locfiledit_filename_error'] = 'Dosya adinda tanimlanamayan karakterler kullanilmis.';
$lang['locfiledit_file_already_exists'] = 'Bu dosya zaten var.';
$lang['locfiledit_model_error'] = 'Model seçmek zorundasin.';
$lang['locfiledit_empty_filename'] = 'Adi doldurmak zorundasin.';
$lang['locfiledit_webmaster_only'] = 'Sadece yöneticiler dosyalari degistirebilir .';

?>
